@@ -490,7 +490,7 @@ troubles."
 (defun encrypt-md5 (plaintext salt)
   (string-downcase
    (format nil "~{~2,'0X~}"
-           (coerce (md5sum-sequence (concatenate 'string plaintext salt)) 'list))))
+           (coerce (md5sum-string (concatenate 'string plaintext salt)) 'list))))
 
 (defun reopen-postgresql-connection (connection)
   "Reopen the given PostgreSQL connection.  Closes any existing
