@@ -190,6 +190,18 @@
     (clsql:sql [not [null]])
   "(NOT (NULL))")
 
+(deftest :syntax/null/5
+    (clsql:sql [is [foo.bar] [null]])
+  "(FOO.BAR IS NULL)")
+
+(deftest :syntax/null/6
+    (clsql:sql [is [foo.bar] [not-null]])
+  "(FOO.BAR IS NOT NULL)")
+
+(deftest :syntax/null/7
+    (clsql:sql [not-null [foo.bar]])
+  "(FOO.BAR IS NOT NULL)")
+
 
 
 (deftest :syntax/relational/1
@@ -405,22 +417,49 @@
                   [like (clsql:sql-expression :table table
                                              :attribute 'baz)
                         (clsql:sql table)])))
-  "(BETWEEN(THISTIME.BAR,(HIP * HOP),42) AND (THISTIME.BAZ LIKE 'THISTIME') AND BETWEEN(NEXTTIME.BAR,(HIP * HOP),43) AND (NEXTTIME.BAZ LIKE 'NEXTTIME') AND BETWEEN(SOMETIME.BAR,(HIP * HOP),44) AND (SOMETIME.BAZ LIKE 'SOMETIME') AND BETWEEN(NEVER.BAR,(HIP * HOP),45) AND (NEVER.BAZ LIKE 'NEVER'))")
+  "(BETWEEN(THISTIME.BAR,(HIP * HOP),42) AND (THISTIME.BAZ LIKE 'THISTIME') AND BETWEEN(NEXTTIME.BAR,(HIP * HOP),43) AND (NEXTTIME.BAZ LIKE 'NEXTTIME') AND BETWEEN(SOMETIME.BAR,(HIP * HOP),44) AND (SOMETIME.BAZ LIKE 'SOMETIME') AND BETWEEN(NEVER.BAR,(HIP * HOP),45) AND (NEVER.BAZ LIKE 'NEVER'))"
+ )
 
-))
+(deftest :syntax/subqueries/query
+ (clsql:sql
+  (clsql:sql-operation 'select [*]
+   :from [foo]
+   :where [in [id] [select [id] :from [bar]]]))
+ "SELECT * FROM FOO WHERE (ID IN (SELECT ID FROM BAR))")
 
-(defun test-output-sql/sql-ident-table ()
-  (let ((tests `((,(make-instance 'sql-ident-table :name :foo) "FOO")
-		 (,(make-instance 'sql-ident-table :name :foo-bar) "FOO_BAR")
-		 (,(make-instance 'sql-ident-table :name "foo") "\"foo\"")
-		 (,(make-instance 'sql-ident-table :name '|foo bar|) "\"foo bar\"")
-		 (,(make-instance 'sql-ident-table :name :foo :table-alias :bar) "FOO BAR" )
-		 (,(make-instance 'sql-ident-table :name :foo_bar :table-alias :bar-bast) "FOO_BAR BAR_BAST")
-		 (,(make-instance 'sql-ident-table :name "foo" :table-alias "Bar") "\"foo\" \"Bar\"")
-		 (,(make-instance 'sql-ident-table :name '|foo bar| :table-alias :bast) "\"foo bar\" BAST"))))
-    (loop for (test expected-result) in tests
-	  for test-out = (with-output-to-string (*sql-stream*) (output-sql test nil))
-	  do (assert (string-equal test-out expected-result)
-		     (test test-out expected-result)
-		     "Test:~s didnt match ~S"
-		     test-out expected-result))))
+(deftest :syntax/subqueries/delete
+ (clsql:sql
+  (make-instance 'clsql-sys::sql-delete
+   :from [foo]
+   :where [in [id] [select [id] :from [bar]]]))
+ "DELETE FROM FOO WHERE (ID IN (SELECT ID FROM BAR))")
+
+(deftest :syntax/subqueries/update
+ (clsql:sql
+  (make-instance 'clsql-sys::sql-update
+   :attributes (list [id])
+   :values '(0)
+   :table [foo]
+   :where [in [id] [select [id] :from [bar]]]))
+ "UPDATE FOO SET ID = 0 WHERE (ID IN (SELECT ID FROM BAR))")
+
+ ))
+
+(let ((tests '(((:foo) "FOO")
+	       ((:foo-bar) "FOO_BAR")
+	       (("foo") "\"foo\"")
+	       (('|foo bar|) "\"foo bar\"")
+	       ((:foo :table-alias :bar) "FOO BAR" )
+	       ((:foo_bar :table-alias :bar-bast) "FOO_BAR BAR_BAST")
+	       (("foo" :table-alias "Bar") "\"foo\" \"Bar\"")
+	       (('|foo bar| :table-alias :bast) "\"foo bar\" BAST"))))
+
+  (push
+   `(deftest :syntax/sql-ident-table
+	(values ,@(mapcar
+		   #'(lambda (args)
+		       `(clsql:sql (make-instance 'clsql-sys:sql-ident-table
+						  :name ,@args)))
+		   (mapcar #'first tests)))
+      ,@(mapcar #'second tests))
+   *rt-syntax*))
